/**
 * Copyright (c) 2003, www.pdfbox.org
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of pdfbox; nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * http://www.pdfbox.org
 *
 */
package org.pdfbox.pdmodel.annotation.interactive;

import java.util.List;

import org.pdfbox.cos.COSBase;
import org.pdfbox.cos.COSDictionary;
import org.pdfbox.cos.COSName;

/**
 * A PDRadioButton is used as a part of PDRadioCollection.
 * The COSRatioButton represents a single radiobutton element
 * in the PDF.
 *
 * @author sug
 * @version $Revision: 1.1 $
 */
public class PDRadioButton
{
    private static final COSName KEY = COSName.getPDFName("AS");
    private static final COSName OFF_VALUE = COSName.getPDFName("Off");

    private COSDictionary obj;
    private COSName value;

    /**
     * Constructs a COSRadioButton from a child of the
     * COSRadioCollection.
     *
     * @param obj The child of a radiobutton collection.
     */
    public PDRadioButton(COSDictionary obj)
    {
        this.obj = obj;
        COSDictionary ap = (COSDictionary) obj.getDictionaryObject(COSName.getPDFName("AP"));
        COSBase n = ap.getDictionaryObject(COSName.getPDFName("N"));

        //N can be a COSDictionary or a COSStream
        if( n instanceof COSDictionary )
        {
            List li = ((COSDictionary)n).keyList();
            value = (COSName) li.get(0);
        }


    }

    /**
     * Checks the radiobutton
     */
    public void check()
    {
        obj.setItem(KEY, value);
    }

    /**
     * Unchecks the radiobutton
     */
    public void unCheck()
    {
        obj.setItem(KEY, OFF_VALUE);
    }

    /**
     * This method determins if the radiobutton represents
     * a given value.
     *
     * @param value the value to check for
     * @return the result of the determination
     */
    public boolean representsValue(COSName value)
    {
        return this.value.equals(value);
    }
}